library(eggCounts)
library(readxl)
library(ggplot2)
library(ggtext)
# Taenia
Taenia <- read_excel("supplementary1_data.xlsx", sheet = "Taenia")
epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
ddd<-fec_stan(epg$epgt, CF=50)
samples <- stan2mcmc(ddd$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samples[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samples[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samples[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
Taenia$lower <- my_functionL1(Taenia$alpha,Taenia$beta)
Taenia$median <- my_functionM1(Taenia$alpha,Taenia$beta)
Taenia$upper <- my_functionU1(Taenia$alpha,Taenia$beta)

Taenia$contL<-Taenia$lower*Taenia$samples*59.7/(Taenia$area*1000000)
Taenia$contM<-Taenia$median*Taenia$samples*59.7/(Taenia$area*1000000)
Taenia$contU<-Taenia$upper*Taenia$samples*59.7/(Taenia$area*1000000)

Taenia$season <- factor(Taenia$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18'))


taenalay<-ggplot(Taenia[21:24,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2)(+/-) 95% CIs")+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  theme(axis.title.y = element_markdown())+ylim(0,20)

taenkochkor<-ggplot(Taenia[45:48,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2)(+/-) 95% CIs")+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  theme(axis.title.y = element_markdown())+ylim(0,20)

require(gridExtra)
grid.arrange(taenalay, taenkochkor, ncol=2)


#E. granulosus
EG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
EG$lower <- my_functionL1(EG$alpha,EG$beta)
EG$median <- my_functionM1(EG$alpha,EG$beta)
EG$upper <- my_functionU1(EG$alpha,EG$beta)

EG$contL<-EG$lower*EG$samples*59.7/(EG$area*1000000)
EG$contM<-EG$median*EG$samples*59.7/(EG$area*1000000)
EG$contU<-EG$upper*EG$samples*59.7/(EG$area*1000000)

EG$season <- factor(EG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18'))

alaiG<-ggplot(EG[21:24,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2) (+/- 95% CIs)")+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  theme(axis.title.y = element_markdown())+
  ylim(0, 10)

kochkorG<-ggplot(EG[45:48,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2) (+/- 95% CI)")+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  theme(axis.title.y = element_markdown())+
  ylim(0, 10)

alaiG<-ggplot(EG[49:52,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2) (+/- 95% CIs)" )+
  theme(axis.title.y = element_markdown())+
  ylim(0, 10)

require(gridExtra)
grid.arrange(alaiG, kochkorG, ncol=2)

#probability of differences in contamination between Kochkor and Alai
ttt<-(rbeta(2000, sum(EG$alpha[21:24])-3, sum(EG$beta[21:24])-3)*samplesG[,1]*59.7)*sum(EG$samples[21:24])/(EG$area[21]*1000000)
ttt1<-(rbeta(2000, sum(EG$alpha[45:48])-3, sum(EG$beta[45:48])-3)*samplesG[,1]*59.7)*sum(EG$samples[45:48])/(EG$area[45]*1000000)
percentile <- ecdf(ttt)
percentile(median(ttt1))

#E. multilocularis
EM <- read_excel("supplementary1_data.xlsx", sheet = "em")
epg <- read_excel("supplementary1_data.xlsx1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
EM$lower <- my_functionL1(EM$alpha,EM$beta)
EM$median <- my_functionM1(EM$alpha,EM$beta)
EM$upper <- my_functionU1(EM$alpha,EM$beta)

EM$contL<-EM$lower*EM$samples*59.7/(EM$area*1000000)
EM$contM<-EM$median*EM$samples*59.7/(EM$area*1000000)
EM$contU<-EM$upper*EM$samples*59.7/(EM$area*1000000)

EM$season <- factor(EM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18'))

alaiM<-ggplot(EM[21:24,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2) (+/- 95% CIs)")+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  theme(axis.title.y = element_markdown())+
  ylim(0,10)

kochkorM<-ggplot(EM[45:48,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Sampling Month", y = "Eggs per metre^(2) (+/- 95% CIs)")+
  theme(text=element_text(color="black"),axis.text=element_text(color="black"))+
  theme(axis.title.y = element_markdown())+
  ylim(0,10)

require(gridExtra)
grid.arrange(alaiM, kochkorM, ncol=2)

ggplot(EM[49:52,]) +
  geom_bar( aes(x=season, y=contM), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL, ymax=contU), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  #xlab("Season") + ylab("Eggs per meter^(2) square")
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#all
#em
All1 <- read_excel("supplementary1_data.xlsx1_data.xlsx",  sheet = "all")

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
All1$lower <- my_functionL1(All1$alpha,All1$beta)
All1$median <- my_functionM1(All1$alpha,All1$beta)
All1$upper <- my_functionU1(All1$alpha,All1$beta)

All1$contL<-All1$lower*All1$samples*59.7/(All1$area*1000000)
All1$contM<-All1$median*All1$samples*59.7/(All1$area*1000000)
All1$contU<-All1$upper*All1$samples*59.7/(All1$area*1000000)

#Cumulative contamination E. multilocularis (table 3 in text)
All1$contL[1]#Kochkor,lower CI cumulative contamination (table 3 in text)
All1$contM[1]#Kochkor,median cumulative contamination (table 3 in text)
All1$contU[1]#Kochkor,upper CI cumulative contamination (table 3 in text)
All1$contL[2]#Alai,lower CI cumulative contamination (table 3 in text)
All1$contM[2]#Alai,median cumulative contamination (table 3 in text)
All1$contU[2]#Alai,upper CI cumulative contamination (table 3 in text)

#eg
AllG <- read_excel("supplementary1_data.xlsx1_data.xlsx",  sheet = "allG")

epg <- read_excel("supplementary1_data.xlsx1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
AllG$lower <- my_functionL1(AllG$alpha,AllG$beta)
AllG$median <- my_functionM1(AllG$alpha,AllG$beta)
AllG$upper <- my_functionU1(AllG$alpha,AllG$beta)

AllG$contL<-AllG$lower*AllG$samples*59.7/(AllG$area*1000000)
AllG$contM<-AllG$median*AllG$samples*59.7/(AllG$area*1000000)
AllG$contU<-AllG$upper*AllG$samples*59.7/(AllG$area*1000000)

#Cumulative contamination E. granulosis (table 3 in text)
AllG$contL[1]#Kochkor,lower CI cumulative contamination (table 3 in text)
AllG$contM[1]#Kochkor,median cumulative contamination (table 3 in text)
AllG$contU[1]#Kochkor,upper CI cumulative contamination (table 3 in text)
AllG$contL[2]#Alai,lower CI cumulative contamination (table 3 in text)
AllG$contM[2]#Alai,median cumulative contamination (table 3 in text)
AllG$contU[2]#Alai,upper CI cumulative contamination (table 3 in text)


#######################################################
#Contamination of each village
#terek-E. multilocularis
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
terekM<-alai_dogM[1:4,]
terekM[nrow(terekM) + 1,]<-list("Total", sum(terekM$alpha)-3, sum(terekM$beta)-3, sum(terekM$samples), "all", 0.41)
epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
terekM$lower <- my_functionL1(terekM$alpha,terekM$beta)
terekM$median <- my_functionM1(terekM$alpha,terekM$beta)
terekM$upper <- my_functionU1(terekM$alpha,terekM$beta)

terekM$contL.terek<-terekM$lower*terekM$samples*59.7/(terekM$area*1000000)
terekM$contM.terek<-terekM$median*terekM$samples*59.7/(terekM$area*1000000)
terekM$contU.terek<-terekM$upper*terekM$samples*59.7/(terekM$area*1000000)

terekM$season <- factor(terekM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(terekM) +
  geom_bar( aes(x=season, y=contM.terek), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.terek, ymax=contU.terek), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())



#Sopukorgon-E. multilocularis
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
SopukorgonM<-alai_dogM[5:8,]
SopukorgonM[nrow(SopukorgonM) + 1,] <- list("Total", sum(SopukorgonM$alpha)-3, sum(SopukorgonM$beta)-3, sum(SopukorgonM$samples),"all", SopukorgonM$area[1])
epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
SopukorgonM$lower <- my_functionL1(SopukorgonM$alpha,SopukorgonM$beta)
SopukorgonM$median <- my_functionM1(SopukorgonM$alpha,SopukorgonM$beta)
SopukorgonM$upper <- my_functionU1(SopukorgonM$alpha,SopukorgonM$beta)

SopukorgonM$contL.Sopukorgon<-SopukorgonM$lower*SopukorgonM$samples*59.7/(SopukorgonM$area*1000000)
SopukorgonM$contM.Sopukorgon<-SopukorgonM$median*SopukorgonM$samples*59.7/(SopukorgonM$area*1000000)
SopukorgonM$contU.Sopukorgon<-SopukorgonM$upper*SopukorgonM$samples*59.7/(SopukorgonM$area*1000000)

SopukorgonM$season <- factor(SopukorgonM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(SopukorgonM) +
  geom_bar( aes(x=season, y=contM.Sopukorgon), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Sopukorgon, ymax=contU.Sopukorgon), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#Segondu-E. multilocularis
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
SegonduM<-alai_dogM[9:12,]
SegonduM[nrow(SegonduM) + 1,] <- list("Total", sum(SegonduM$alpha)-3, sum(SegonduM$beta)-3, sum(SegonduM$samples), "all", SegonduM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
SegonduM$lower <- my_functionL1(SegonduM$alpha,SegonduM$beta)
SegonduM$median <- my_functionM1(SegonduM$alpha,SegonduM$beta)
SegonduM$upper <- my_functionU1(SegonduM$alpha,SegonduM$beta)

SegonduM$contL.Segondu<-SegonduM$lower*SegonduM$samples*59.7/(SegonduM$area*1000000)
SegonduM$contM.Segondu<-SegonduM$median*SegonduM$samples*59.7/(SegonduM$area*1000000)
SegonduM$contU.Segondu<-SegonduM$upper*SegonduM$samples*59.7/(SegonduM$area*1000000)

SegonduM$season <- factor(SegonduM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(SegonduM) +
  geom_bar( aes(x=season, y=contM.Segondu), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Segondu, ymax=contU.Segondu), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#kunelek-E. multilocularis
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
kunelekM<-alai_dogM[13:16,]
kunelekM[nrow(kunelekM) + 1,] <- list("Total", sum(kunelekM$alpha)-3, sum(kunelekM$beta)-3, sum(kunelekM$samples), "all", kunelekM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
kunelekM$lower <- my_functionL1(kunelekM$alpha,kunelekM$beta)
kunelekM$median <- my_functionM1(kunelekM$alpha,kunelekM$beta)
kunelekM$upper <- my_functionU1(kunelekM$alpha,kunelekM$beta)

kunelekM$contL.kunelek<-kunelekM$lower*kunelekM$samples*59.7/(kunelekM$area*1000000)
kunelekM$contM.kunelek<-kunelekM$median*kunelekM$samples*59.7/(kunelekM$area*1000000)
kunelekM$contU.kunelek<-kunelekM$upper*kunelekM$samples*59.7/(kunelekM$area*1000000)

kunelekM$season <- factor(kunelekM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(kunelekM) +
  geom_bar( aes(x=season, y=contM.kunelek), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.kunelek, ymax=contU.kunelek), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#Chitala
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
ChitalaM<-alai_dogM[17:20,]
ChitalaM[nrow(ChitalaM) + 1,] <- list("Total", sum(ChitalaM$alpha)-3, sum(ChitalaM$beta)-3, sum(ChitalaM$samples), "all", ChitalaM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
ChitalaM$lower <- my_functionL1(ChitalaM$alpha,ChitalaM$beta)
ChitalaM$median <- my_functionM1(ChitalaM$alpha,ChitalaM$beta)
ChitalaM$upper <- my_functionU1(ChitalaM$alpha,ChitalaM$beta)

ChitalaM$contL.Chitala<-ChitalaM$lower*ChitalaM$samples*59.7/(ChitalaM$area*1000000)
ChitalaM$contM.Chitala<-ChitalaM$median*ChitalaM$samples*59.7/(ChitalaM$area*1000000)
ChitalaM$contU.Chitala<-ChitalaM$upper*ChitalaM$samples*59.7/(ChitalaM$area*1000000)

ChitalaM$season <- factor(ChitalaM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(ChitalaM) +
  geom_bar( aes(x=season, y=contM.Chitala), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Chitala, ymax=contU.Chitala), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#MantyshM
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
MantyshM<-alai_dogM[25:28,]
MantyshM[nrow(MantyshM) + 1,] <- list("Total", sum(MantyshM$alpha)-3, sum(MantyshM$beta)-3, sum(MantyshM$samples), "all", MantyshM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
MantyshM$lower <- my_functionL1(MantyshM$alpha,MantyshM$beta)
MantyshM$median <- my_functionM1(MantyshM$alpha,MantyshM$beta)
MantyshM$upper <- my_functionU1(MantyshM$alpha,MantyshM$beta)

MantyshM$contL.Mantysh<-MantyshM$lower*MantyshM$samples*59.7/(MantyshM$area*1000000)
MantyshM$contM.Mantysh<-MantyshM$median*MantyshM$samples*59.7/(MantyshM$area*1000000)
MantyshM$contU.Mantysh<-MantyshM$upper*MantyshM$samples*59.7/(MantyshM$area*1000000)

MantyshM$season <- factor(MantyshM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(MantyshM) +
  geom_bar( aes(x=season, y=contM.Mantysh), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Mantysh, ymax=contU.Mantysh), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#KomsomolM
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
KomsomolM<-alai_dogM[29:32,]
KomsomolM[nrow(KomsomolM) + 1,] <- list("Total", sum(KomsomolM$alpha)-3, sum(KomsomolM$beta)-3, sum(KomsomolM$samples), "all", KomsomolM$area[1])

epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
KomsomolM$lower <- my_functionL1(KomsomolM$alpha,KomsomolM$beta)
KomsomolM$median <- my_functionM1(KomsomolM$alpha,KomsomolM$beta)
KomsomolM$upper <- my_functionU1(KomsomolM$alpha,KomsomolM$beta)

KomsomolM$contL.Komsomol<-KomsomolM$lower*KomsomolM$samples*59.7/(KomsomolM$area*1000000)
KomsomolM$contM.Komsomol<-KomsomolM$median*KomsomolM$samples*59.7/(KomsomolM$area*1000000)
KomsomolM$contU.Komsomol<-KomsomolM$upper*KomsomolM$samples*59.7/(KomsomolM$area*1000000)

KomsomolM$season <- factor(KomsomolM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(KomsomolM) +
  geom_bar( aes(x=season, y=contM.Komsomol), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Komsomol, ymax=contU.Komsomol), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#DonalyshM
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
DonalyshM<-alai_dogM[33:36,]
DonalyshM[nrow(DonalyshM) + 1,] <- list("Total", sum(DonalyshM$alpha)-3, sum(DonalyshM$beta)-3, sum(DonalyshM$samples), "all", DonalyshM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
DonalyshM$lower <- my_functionL1(DonalyshM$alpha,DonalyshM$beta)
DonalyshM$median <- my_functionM1(DonalyshM$alpha,DonalyshM$beta)
DonalyshM$upper <- my_functionU1(DonalyshM$alpha,DonalyshM$beta)

DonalyshM$contL.Donalysh<-DonalyshM$lower*DonalyshM$samples*59.7/(DonalyshM$area*1000000)
DonalyshM$contM.Donalysh<-DonalyshM$median*DonalyshM$samples*59.7/(DonalyshM$area*1000000)
DonalyshM$contU.Donalysh<-DonalyshM$upper*DonalyshM$samples*59.7/(DonalyshM$area*1000000)

DonalyshM$season <- factor(DonalyshM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(DonalyshM) +
  geom_bar( aes(x=season, y=contM.Donalysh), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Donalysh, ymax=contU.Donalysh), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#ChekildekhM
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
ChekildekhM<-alai_dogM[37:40,]
ChekildekhM[nrow(ChekildekhM) + 1,] <- list("Total", sum(ChekildekhM$alpha)-3, sum(ChekildekhM$beta)-3, sum(ChekildekhM$samples), "all", ChekildekhM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
ChekildekhM$lower <- my_functionL1(ChekildekhM$alpha,ChekildekhM$beta)
ChekildekhM$median <- my_functionM1(ChekildekhM$alpha,ChekildekhM$beta)
ChekildekhM$upper <- my_functionU1(ChekildekhM$alpha,ChekildekhM$beta)

ChekildekhM$contL.Chekildekh<-ChekildekhM$lower*ChekildekhM$samples*59.7/(ChekildekhM$area*1000000)
ChekildekhM$contM.Chekildekh<-ChekildekhM$median*ChekildekhM$samples*59.7/(ChekildekhM$area*1000000)
ChekildekhM$contU.Chekildekh<-ChekildekhM$upper*ChekildekhM$samples*59.7/(ChekildekhM$area*1000000)

ChekildekhM$season <- factor(ChekildekhM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(ChekildekhM) +
  geom_bar( aes(x=season, y=contM.Chekildekh), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Chekildekh, ymax=contU.Chekildekh), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#	AkTalaaM
alai_dogM <- read_excel("supplementary1_data.xlsx", sheet = "em")
AkTalaaM<-alai_dogM[41:44,]
AkTalaaM[nrow(AkTalaaM) + 1,] <- list("Total", sum(AkTalaaM$alpha)-3, sum(AkTalaaM$beta)-3, sum(AkTalaaM$samples), "all", AkTalaaM$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddM<-fec_stan(epg$epgm[1:42], CF=50)
samplesM <- stan2mcmc(dddM$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesM[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
AkTalaaM$lower <- my_functionL1(AkTalaaM$alpha,AkTalaaM$beta)
AkTalaaM$median <- my_functionM1(AkTalaaM$alpha,AkTalaaM$beta)
AkTalaaM$upper <- my_functionU1(AkTalaaM$alpha,AkTalaaM$beta)

AkTalaaM$contL.AkTalaa<-AkTalaaM$lower*AkTalaaM$samples*59.7/(AkTalaaM$area*1000000)
AkTalaaM$contM.AkTalaa<-AkTalaaM$median*AkTalaaM$samples*59.7/(AkTalaaM$area*1000000)
AkTalaaM$contU.AkTalaa<-AkTalaaM$upper*AkTalaaM$samples*59.7/(AkTalaaM$area*1000000)

AkTalaaM$season <- factor(AkTalaaM$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(AkTalaaM) +
  geom_bar( aes(x=season, y=contM.AkTalaa), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.AkTalaa, ymax=contU.AkTalaa), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#E.granulosus by village....

#terek-E. granulosus
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
terekG<-alai_dogG[1:4,]
terekG[nrow(terekG) + 1,] <- list("Total", sum(terekG$alpha)-3, sum(terekG$beta)-3, sum(terekG$samples), "all", terekG$area[1])

epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
terekG$lower <- my_functionL1(terekG$alpha,terekG$beta)
terekG$median <- my_functionM1(terekG$alpha,terekG$beta)
terekG$upper <- my_functionU1(terekG$alpha,terekG$beta)

terekG$contL.terek<-terekG$lower*terekG$samples*59.7/(terekG$area*1000000)
terekG$contM.terek<-terekG$median*terekG$samples*59.7/(terekG$area*1000000)
terekG$contU.terek<-terekG$upper*terekG$samples*59.7/(terekG$area*1000000)

terekG$season <- factor(terekG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(terekG) +
  geom_bar( aes(x=season, y=contM.terek), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.terek, ymax=contU.terek), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#Sopukorgon-E. granulosus
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
SopukorgonG<-alai_dogG[5:8,]
SopukorgonG[nrow(SopukorgonG) + 1,] <- list("Total", sum(SopukorgonG$alpha)-3, sum(SopukorgonG$beta)-3, sum(SopukorgonG$samples), "all", SopukorgonG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionG <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
SopukorgonG$lower <- my_functionL1(SopukorgonG$alpha,SopukorgonG$beta)
SopukorgonG$median <- my_functionM1(SopukorgonG$alpha,SopukorgonG$beta)
SopukorgonG$upper <- my_functionU1(SopukorgonG$alpha,SopukorgonG$beta)

SopukorgonG$contL.Sopukorgon<-SopukorgonG$lower*SopukorgonG$samples*59.7/(SopukorgonG$area*1000000)
SopukorgonG$contM.Sopukorgon<-SopukorgonG$median*SopukorgonG$samples*59.7/(SopukorgonG$area*1000000)
SopukorgonG$contU.Sopukorgon<-SopukorgonG$upper*SopukorgonG$samples*59.7/(SopukorgonG$area*1000000)

SopukorgonG$season <- factor(SopukorgonG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(SopukorgonG) +
  geom_bar( aes(x=season, y=contM.Sopukorgon), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Sopukorgon, ymax=contU.Sopukorgon), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#Segondu-E. granulosus
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
SegonduG<-alai_dogG[9:12,]
SegonduG[nrow(SegonduG) + 1,] <- list("Total", sum(SegonduG$alpha)-3, sum(SegonduG$beta)-3, sum(SegonduG$samples), "all", SegonduG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
SegonduG$lower <- my_functionL1(SegonduG$alpha,SegonduG$beta)
SegonduG$median <- my_functionM1(SegonduG$alpha,SegonduG$beta)
SegonduG$upper <- my_functionU1(SegonduG$alpha,SegonduG$beta)

SegonduG$contL.Segondu<-SegonduG$lower*SegonduG$samples*59.7/(SegonduG$area*1000000)
SegonduG$contM.Segondu<-SegonduG$median*SegonduG$samples*59.7/(SegonduG$area*1000000)
SegonduG$contU.Segondu<-SegonduG$upper*SegonduG$samples*59.7/(SegonduG$area*1000000)

SegonduG$season <- factor(SegonduG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(SegonduG) +
  geom_bar( aes(x=season, y=contM.Segondu), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Segondu, ymax=contU.Segondu), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#kunelek-E. granulosus
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
kunelekG<-alai_dogG[13:16,]
kunelekG[nrow(kunelekG) + 1,] <- list("Total", sum(kunelekG$alpha)-3, sum(kunelekG$beta)-3, sum(kunelekG$samples), "all", kunelekG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionG <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
kunelekG$lower <- my_functionL1(kunelekG$alpha,kunelekG$beta)
kunelekG$median <- my_functionM1(kunelekG$alpha,kunelekG$beta)
kunelekG$upper <- my_functionU1(kunelekG$alpha,kunelekG$beta)

kunelekG$contL.kunelek<-kunelekG$lower*kunelekG$samples*59.7/(kunelekG$area*1000000)
kunelekG$contM.kunelek<-kunelekG$median*kunelekG$samples*59.7/(kunelekG$area*1000000)
kunelekG$contU.kunelek<-kunelekG$upper*kunelekG$samples*59.7/(kunelekG$area*1000000)

kunelekG$season <- factor(kunelekG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(kunelekG) +
  geom_bar( aes(x=season, y=contM.kunelek), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.kunelek, ymax=contU.kunelek), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#Chitala
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
ChitalaG<-alai_dogG[17:20,]
ChitalaG[nrow(ChitalaG) + 1,] <- list("Total", sum(ChitalaG$alpha)-3, sum(ChitalaG$beta)-3, sum(ChitalaG$samples), "all", ChitalaG$area[1])

epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
ChitalaG$lower <- my_functionL1(ChitalaG$alpha,ChitalaG$beta)
ChitalaG$median <- my_functionM1(ChitalaG$alpha,ChitalaG$beta)
ChitalaG$upper <- my_functionU1(ChitalaG$alpha,ChitalaG$beta)

ChitalaG$contL.Chitala<-ChitalaG$lower*ChitalaG$samples*59.7/(ChitalaG$area*1000000)
ChitalaG$contM.Chitala<-ChitalaG$median*ChitalaG$samples*59.7/(ChitalaG$area*1000000)
ChitalaG$contU.Chitala<-ChitalaG$upper*ChitalaG$samples*59.7/(ChitalaG$area*1000000)

ChitalaG$season <- factor(ChitalaG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(ChitalaG) +
  geom_bar( aes(x=season, y=contM.Chitala), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Chitala, ymax=contU.Chitala), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

#MantyshG
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
MantyshG<-alai_dogG[25:28,]
MantyshG[nrow(MantyshG) + 1,] <- list("Total", sum(MantyshG$alpha)-3, sum(MantyshG$beta)-3, sum(MantyshG$samples), "all", MantyshG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
MantyshG$lower <- my_functionL1(MantyshG$alpha,MantyshG$beta)
MantyshG$median <- my_functionM1(MantyshG$alpha,MantyshG$beta)
MantyshG$upper <- my_functionU1(MantyshG$alpha,MantyshG$beta)

MantyshG$contL.Mantysh<-MantyshG$lower*MantyshG$samples*59.7/(MantyshG$area*1000000)
MantyshG$contM.Mantysh<-MantyshG$median*MantyshG$samples*59.7/(MantyshG$area*1000000)
MantyshG$contU.Mantysh<-MantyshG$upper*MantyshG$samples*59.7/(MantyshG$area*1000000)

MantyshG$season <- factor(MantyshG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(MantyshG) +
  geom_bar( aes(x=season, y=contM.Mantysh), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Mantysh, ymax=contU.Mantysh), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#KomsomolG
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
KomsomolG<-alai_dogG[29:32,]
KomsomolG[nrow(KomsomolG) + 1,] <- list("Total", sum(KomsomolG$alpha)-3, sum(KomsomolG$beta)-3, sum(KomsomolG$samples), "all", KomsomolG$area[1])

epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
KomsomolG$lower <- my_functionL1(KomsomolG$alpha,KomsomolG$beta)
KomsomolG$median <- my_functionM1(KomsomolG$alpha,KomsomolG$beta)
KomsomolG$upper <- my_functionU1(KomsomolG$alpha,KomsomolG$beta)

KomsomolG$contL.Komsomol<-KomsomolG$lower*KomsomolG$samples*59.7/(KomsomolG$area*1000000)
KomsomolG$contM.Komsomol<-KomsomolG$median*KomsomolG$samples*59.7/(KomsomolG$area*1000000)
KomsomolG$contU.Komsomol<-KomsomolG$upper*KomsomolG$samples*59.7/(KomsomolG$area*1000000)

KomsomolG$season <- factor(KomsomolG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(KomsomolG) +
  geom_bar( aes(x=season, y=contM.Komsomol), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Komsomol, ymax=contU.Komsomol), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#Donalysh
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
DonalyshG<-alai_dogG[33:36,]
DonalyshG[nrow(DonalyshG) + 1,] <- list("Total", sum(DonalyshG$alpha)-3, sum(DonalyshG$beta)-3, sum(DonalyshG$samples), "all", DonalyshG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
DonalyshG$lower <- my_functionL1(DonalyshG$alpha,DonalyshG$beta)
DonalyshG$median <- my_functionM1(DonalyshG$alpha,DonalyshG$beta)
DonalyshG$upper <- my_functionU1(DonalyshG$alpha,DonalyshG$beta)

DonalyshG$contL.Donalysh<-DonalyshG$lower*DonalyshG$samples*59.7/(DonalyshG$area*1000000)
DonalyshG$contM.Donalysh<-DonalyshG$median*DonalyshG$samples*59.7/(DonalyshG$area*1000000)
DonalyshG$contU.Donalysh<-DonalyshG$upper*DonalyshG$samples*59.7/(DonalyshG$area*1000000)

DonalyshG$season <- factor(DonalyshG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(DonalyshG) +
  geom_bar( aes(x=season, y=contM.Donalysh), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Donalysh, ymax=contU.Donalysh), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#ChekildekhG
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
ChekildekhG<-alai_dogG[37:40,]
ChekildekhG[nrow(ChekildekhG) + 1,] <- list("Total", sum(ChekildekhG$alpha)-3, sum(ChekildekhG$beta)-3, sum(ChekildekhG$samples), "all", ChekildekhG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
ChekildekhG$lower <- my_functionL1(ChekildekhG$alpha,ChekildekhG$beta)
ChekildekhG$median <- my_functionM1(ChekildekhG$alpha,ChekildekhG$beta)
ChekildekhG$upper <- my_functionU1(ChekildekhG$alpha,ChekildekhG$beta)

ChekildekhG$contL.Chekildekh<-ChekildekhG$lower*ChekildekhG$samples*59.7/(ChekildekhG$area*1000000)
ChekildekhG$contM.Chekildekh<-ChekildekhG$median*ChekildekhG$samples*59.7/(ChekildekhG$area*1000000)
ChekildekhG$contU.Chekildekh<-ChekildekhG$upper*ChekildekhG$samples*59.7/(ChekildekhG$area*1000000)

ChekildekhG$season <- factor(ChekildekhG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(ChekildekhG) +
  geom_bar( aes(x=season, y=contM.Chekildekh), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.Chekildekh, ymax=contU.Chekildekh), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())


#	AkTalaaG
alai_dogG <- read_excel("supplementary1_data.xlsx", sheet = "eg")
AkTalaaG<-alai_dogG[41:44,]
AkTalaaG[nrow(AkTalaaG) + 1,] <- list("Total", sum(AkTalaaG$alpha)-3, sum(AkTalaaG$beta)-3, sum(AkTalaaG$samples), "all", AkTalaaG$area[1])


epg <- read_excel("supplementary1_data.xlsx", sheet="epg")
dddG<-fec_stan(epg$epgg[1:26], CF=50)
samplesG <- stan2mcmc(dddG$stan.samples)

my_functionL <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.025))
}

my_functionM <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.5))
}

my_functionU <- function(x,y) {
  return (quantile((rbeta(2000, x, y))*samplesG[,1], 0.975))
}

my_functionL1 <- Vectorize(my_functionL)
my_functionM1 <- Vectorize(my_functionM)
my_functionU1 <- Vectorize(my_functionU)
AkTalaaG$lower <- my_functionL1(AkTalaaG$alpha,AkTalaaG$beta)
AkTalaaG$median <- my_functionM1(AkTalaaG$alpha,AkTalaaG$beta)
AkTalaaG$upper <- my_functionU1(AkTalaaG$alpha,AkTalaaG$beta)

AkTalaaG$contL.AkTalaa<-AkTalaaG$lower*AkTalaaG$samples*59.7/(AkTalaaG$area*1000000)
AkTalaaG$contM.AkTalaa<-AkTalaaG$median*AkTalaaG$samples*59.7/(AkTalaaG$area*1000000)
AkTalaaG$contU.AkTalaa<-AkTalaaG$upper*AkTalaaG$samples*59.7/(AkTalaaG$area*1000000)

AkTalaaG$season <- factor(AkTalaaG$season, levels = c('Sept17', 'Feb18', 'June18', 'Nov18', 'all'))

ggplot(AkTalaaG) +
  geom_bar( aes(x=season, y=contM.AkTalaa), stat="identity", fill="skyblue", alpha=0.7) +
  geom_errorbar( aes(x=season, ymin=contL.AkTalaa, ymax=contU.AkTalaa), width=0.4, colour="orange", alpha=0.9, size=1.3)+
  labs(x = "Season", y = "Eggs per metre^(2)")+
  theme(axis.title.y = element_markdown())

